@@ -24,6 +24,7 @@ from .fun_win import find_software_install_path
 from .fun_base import log, hostname, send_exception
 from .fun_file import check_progress_json_ex, get_progress_json_ex, done_progress_json_ex, write_dict_to_file_ex
 
+
 class ZiniaoClient:
     """紫鸟客户端管理类"""
 
@@ -52,7 +53,7 @@ class ZiniaoClient:
     def _get_user_info(self) -> Dict[str, str]:
         """获取用户登录信息"""
         return {
-            "company" : self.config.ziniao.company,
+            "company": self.config.ziniao.company,
             "username": self.config.ziniao.username,
             "password": self.config.ziniao.password
         }
@@ -89,7 +90,7 @@ class ZiniaoClient:
     def update_core(self):
         """下载所有内核，打开店铺前调用，需客户端版本5.285.7以上"""
         data = {
-            "action"   : "updateCore",
+            "action": "updateCore",
             "requestId": str(uuid.uuid4()),
         }
         data.update(self.user_info)
@@ -145,6 +146,7 @@ class ZiniaoClient:
         print('@@ get_exit...' + json.dumps(data))
         self.send_http(data)
 
+
 class ZiniaoBrowser:
     """紫鸟浏览器操作类"""
 
@@ -153,22 +155,22 @@ class ZiniaoBrowser:
         self.config = config
 
     def open_store(self, store_info: str, isWebDriverReadOnlyMode: int = 0,
-            isprivacy: int = 0, isHeadless: int = 0,
-            cookieTypeSave: int = 0, jsInfo: str = "") -> Dict[str, Any]:
+                   isprivacy: int = 0, isHeadless: int = 0,
+                   cookieTypeSave: int = 0, jsInfo: str = "") -> Dict[str, Any]:
         """打开店铺"""
         request_id = str(uuid.uuid4())
         data = {
-            "action"                 : "startBrowser",
-            "isWaitPluginUpdate"     : 0,
-            "isHeadless"             : isHeadless,
-            "requestId"              : request_id,
+            "action": "startBrowser",
+            "isWaitPluginUpdate": 0,
+            "isHeadless": isHeadless,
+            "requestId": request_id,
             "isWebDriverReadOnlyMode": isWebDriverReadOnlyMode,
-            "cookieTypeLoad"         : 0,
-            "cookieTypeSave"         : cookieTypeSave,
-            "runMode"                : "1",
-            "isLoadUserPlugin"       : False,
-            "pluginIdType"           : 1,
-            "privacyMode"            : isprivacy
+            "cookieTypeLoad": 0,
+            "cookieTypeSave": cookieTypeSave,
+            "runMode": "1",
+            "isLoadUserPlugin": False,
+            "pluginIdType": 1,
+            "privacyMode": isprivacy
         }
         data.update(self.client.user_info)
 
@@ -194,9 +196,9 @@ class ZiniaoBrowser:
         """关闭店铺"""
         request_id = str(uuid.uuid4())
         data = {
-            "action"      : "stopBrowser",
-            "requestId"   : request_id,
-            "duplicate"   : 0,
+            "action": "stopBrowser",
+            "requestId": request_id,
+            "duplicate": 0,
             "browserOauth": browser_oauth
         }
         data.update(self.client.user_info)
@@ -215,7 +217,7 @@ class ZiniaoBrowser:
         """获取浏览器列表"""
         request_id = str(uuid.uuid4())
         data = {
-            "action"   : "getBrowserList",
+            "action": "getBrowserList",
             "requestId": request_id
         }
         data.update(self.client.user_info)
@@ -265,6 +267,7 @@ class ZiniaoBrowser:
         # 标记完成
         done_progress_json_ex(self.config, task_key, store_name)
 
+
 class ZiniaoTaskManager:
     """紫鸟任务管理类"""
 
@@ -273,10 +276,10 @@ class ZiniaoTaskManager:
         self.config = config
 
     def run_single_store_task(self, browser_info: Dict[str, Any],
-            run_func: Callable, task_key: str,
-            just_store_username: Optional[List[str]] = None,
-            is_skip_store: Optional[Callable] = None
-    ):
+                              run_func: Callable, task_key: str,
+                              just_store_username: Optional[List[str]] = None,
+                              is_skip_store: Optional[Callable] = None
+                              ):
         """运行单个店铺的任务"""
         retry_count = 0
         while True:
@@ -288,7 +291,8 @@ class ZiniaoTaskManager:
                 store_username = browser_info.get("store_username")
 
                 # 记录店铺账号与店铺别名对应关系
-                write_dict_to_file_ex(self.config.shein_store_alias, {store_username: store_name}, [store_username])
+                cache_file = f'{self.config.auto_dir}/shein_store_alias.json'
+                write_dict_to_file_ex(cache_file, {store_username: store_name}, [store_username])
 
                 if is_skip_store and is_skip_store(store_username, store_name):
                     return
@@ -341,25 +345,25 @@ class ZiniaoTaskManager:
                         self.browser.close_store(store_id)
                     break
             except:
-                send_exception(self.config, f'第{retry_count}次运行失败，准备重新打开店铺')
+                send_exception(f'第{retry_count}次运行失败，准备重新打开店铺')
                 if retry_count > 5:
                     break
 
     def run_all_stores_task(self, browser_list: List[Dict[str, Any]],
-            run_func: Callable, task_key: str,
-            just_store_username: Optional[List[str]] = None,
-            is_skip_store: Optional[Callable] = None
-    ):
+                            run_func: Callable, task_key: str,
+                            just_store_username: Optional[List[str]] = None,
+                            is_skip_store: Optional[Callable] = None
+                            ):
         """循环运行所有店铺的任务"""
         for browser_info in browser_list:
             self.run_single_store_task(browser_info, run_func, task_key, just_store_username, is_skip_store)
 
     def run_with_thread_pool(self, browser_list: List[Dict[str, Any]],
-            max_threads: int = 3, run_func: Callable = None,
-            task_key: str = None,
-            just_store_username: Optional[List[str]] = None,
-            is_skip_store: Optional[Callable] = None
-    ):
+                             max_threads: int = 3, run_func: Callable = None,
+                             task_key: str = None,
+                             just_store_username: Optional[List[str]] = None,
+                             is_skip_store: Optional[Callable] = None
+                             ):
         """使用线程池控制最大并发线程数运行任务"""
         with ThreadPoolExecutor(max_workers=max_threads) as executor:
             task = partial(self.run_single_store_task,
@@ -369,23 +373,27 @@ class ZiniaoTaskManager:
             log(f'店铺总数: {len(browser_list)}')
             executor.map(task, browser_list)
 
+
 class ZiniaoRunner:
     """紫鸟主运行器类"""
 
     def __init__(self, config):
         self.config = config
+        os.environ['auto_dir'] = self.config.auto_dir
+        os.environ['wxwork_bot_exception'] = self.config.wxwork_bot_exception
+
         self.client = ZiniaoClient(config)
         self.browser = ZiniaoBrowser(self.client, config)
         self.task_manager = ZiniaoTaskManager(self.browser, config)
 
     def execute(self, run_prepare: Optional[Callable] = None,
-            run: Optional[Callable] = None,
-            run_summary: Optional[Callable] = None,
-            run_notify: Optional[Callable] = None,
-            task_key: Optional[str] = None,
-            just_store_username: Optional[List[str]] = None,
-            is_skip_store: Optional[Callable] = None,
-    ):
+                run: Optional[Callable] = None,
+                run_summary: Optional[Callable] = None,
+                run_notify: Optional[Callable] = None,
+                task_key: Optional[str] = None,
+                just_store_username: Optional[List[str]] = None,
+                is_skip_store: Optional[Callable] = None,
+                ):
         """主执行入口"""
         # 前置执行 if run_prepare:
         run_prepare()
@@ -414,10 +422,10 @@ class ZiniaoRunner:
         try_times = 0
         while not check_progress_json_ex(self.config, task_key, just_store_username):
             try_times += 1
-            send_exception(self.config, f'检测到任务未全部完成,再次执行: {try_times}')
+            send_exception(f'检测到任务未全部完成,再次执行: {try_times}')
             self.task_manager.run_with_thread_pool(browser_list, max_threads, run, task_key, just_store_username, is_skip_store)
             if try_times >= 4:
-                send_exception(self.config, f'检测到任务未全部完成,再次执行: {try_times}')
+                send_exception(f'检测到任务未全部完成,再次执行: {try_times}')
                 break
 
         # 数据汇总
@@ -437,5 +445,6 @@ class ZiniaoRunner:
         # 关闭客户端
         self.client.exit()
 
+
 if __name__ == "__main__":
     pass
